summaryrefslogtreecommitdiff
path: root/render/box.h
diff options
context:
space:
mode:
authorMichael Drake <tlsa@netsurf-browser.org>2011-06-14 20:00:18 +0000
committerMichael Drake <tlsa@netsurf-browser.org>2011-06-14 20:00:18 +0000
commit53f4da342088e0fe685034d0582cbf6fa13527ae (patch)
tree063970a74db5d904993cd2cc392f5e07f211b6a4 /render/box.h
parent6ed9b1de8bb2aa5220c60fbf0b42aea78f889da1 (diff)
downloadnetsurf-53f4da342088e0fe685034d0582cbf6fa13527ae.tar.gz
netsurf-53f4da342088e0fe685034d0582cbf6fa13527ae.tar.bz2
First pass at core iframes. Currently lacking scrollbars.
svn path=/trunk/netsurf/; revision=12474
Diffstat (limited to 'render/box.h')
-rw-r--r--render/box.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/render/box.h b/render/box.h
index 936c57337..99f67ee1f 100644
--- a/render/box.h
+++ b/render/box.h
@@ -127,7 +127,8 @@ typedef enum {
HAS_HEIGHT = 1 << 6, /* box has height (perhaps due to children) */
MAKE_HEIGHT = 1 << 7, /* box causes its own height */
NEED_MIN = 1 << 8, /* minimum width is required for layout */
- REPLACE_DIM = 1 << 9 /* replaced element has given dimensions */
+ REPLACE_DIM = 1 << 9, /* replaced element has given dimensions */
+ IFRAME = 1 << 10 /* box contains an iframe */
} box_flags;
/* Sides of a box */
@@ -257,6 +258,9 @@ struct box {
struct hlcache_handle* object;
/** Parameters for the object, or 0. */
struct object_params *object_params;
+
+ /** Iframe's browser_window, or NULL if none */
+ struct browser_window *iframe;
};
/** Table column data. */